@@ -7,12 +7,11 @@ Test IPython/Jupyter display hooks
 
 from __future__ import annotations
 
-import shutil
 import subprocess
 from io import BytesIO
 
 import pytest
-from PIL import Image
+from conftest import fails_if_no_mutool
 
 import pikepdf
 
@@ -54,20 +53,16 @@ def test_draw_page(pal, monkeypatch):
         'image/png' not in mimebundle
     ), "Generated image/png when mudraw() was rigged to fail"
 
-    def return_simple_png(prog_args, *args, **kwargs):
-        im = Image.new('1', (1, 1))
-        bio = BytesIO()
-        im.save(bio, format='PNG')
-        bio.seek(0)
-        return subprocess.CompletedProcess(prog_args, 0, stdout=bio.read(), stderr=b'')
+    def mudraw_return_svg(buffer, fmt):
+        return b'<svg xmlns="http://www.w3.org/2000/svg"></svg>'
 
-    monkeypatch.setattr(pikepdf._methods, 'run', return_simple_png)
+    monkeypatch.setattr(pikepdf._methods, '_mudraw', mudraw_return_svg)
     mimebundle = page0._repr_mimebundle_(
-        include=['image/png'], exclude=['application/pdf']
+        include=['image/svg+xml'], exclude=['application/pdf']
     )
     assert (
-        'image/png' in mimebundle
-    ), "Did not generate image/png when mudraw() was rigged to succeed"
+        'image/svg+xml' in mimebundle
+    ), "Did not generate image/svg+xml when mudraw() was rigged to succeed"
 
 
 def test_display_image(pal):
@@ -77,6 +72,7 @@ def test_display_image(pal):
     assert result[1:4] == b'PNG'
 
 
+@fails_if_no_mutool
 def test_display_pdf(pal):
     mimebundle = pal._repr_mimebundle_(
         include=['application/pdf'], exclude=['text/css']
